@@ -42,6 +42,7 @@ static void show_help(const char *name)
        "   -D             : start as a daemon\n"
        "   -v             : show version number and exit\n"
        "   -h             : show this message and exit\n"
+       "   -k             : use <id> config section\n"
        "\n", name);
 }
 
@@ -104,6 +105,7 @@ int main(int argc, const char *const argv[])
     ogs_getopt_t options;
     struct {
         char *config_file;
+        char *config_section;
         char *log_file;
         char *log_level;
         char *domain_mask;
@@ -116,7 +118,7 @@ int main(int argc, const char *const argv[])
     memset(&optarg, 0, sizeof(optarg));
 
     ogs_getopt_init(&options, (char**)argv);
-    while ((opt = ogs_getopt(&options, "vhDc:l:e:m:dt")) != -1) {
+    while ((opt = ogs_getopt(&options, "vhDc:l:e:m:dtk:")) != -1) {
         switch (opt) {
         case 'v':
             show_version();
@@ -164,6 +166,9 @@ int main(int argc, const char *const argv[])
         case 't':
             optarg.enable_trace = true;
             break;
+        case 'k':
+            optarg.config_section = options.optarg;
+            break;
         case '?':
             fprintf(stderr, "%s: %s\n", argv[0], options.errmsg);
             show_help(argv[0]);
@@ -196,6 +201,10 @@ int main(int argc, const char *const argv[])
         argv_out[i++] = "-m";
         argv_out[i++] = optarg.domain_mask;
     }
+    if (optarg.config_section) {
+        argv_out[i++] = "-k";
+        argv_out[i++] = optarg.config_section;
+    }
 
     argv_out[i] = NULL;
 
